package org.xtext.example.mydsl.ui.addons.properties;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.dialogs.PropertyPage;
import org.xtext.example.mydsl.properties.Properties;

public class TextPropertyPage extends PropertyPage {

	private static final String TEXT_TITLE = "Text:";

	private static final int TEXT_FIELD_WIDTH = 50;

	private Text textText;

	/**
	 * Constructor for SamplePropertyPage.
	 */
	public TextPropertyPage() {
		super();
	}

	private void addTextSection(Composite parent) {
		Composite composite = createDefaultComposite(parent);

		Label textLabel = new Label(composite, SWT.NONE);
		textLabel.setText(TEXT_TITLE);

		textText = new Text(composite, SWT.SINGLE | SWT.BORDER);
		GridData gd = new GridData();
		gd.widthHint = convertWidthInCharsToPixels(TEXT_FIELD_WIDTH);
		textText.setLayoutData(gd);

		textText.setText(Properties.getText(getProject()));
	}

	private IProject getProject() {
		return (IProject) getElement().getAdapter(IProject.class);
	}

	/**
	 * @see PreferencePage#createContents(Composite)
	 */
	protected Control createContents(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		GridLayout layout = new GridLayout();
		composite.setLayout(layout);
		GridData data = new GridData(GridData.FILL);
		data.grabExcessHorizontalSpace = true;
		composite.setLayoutData(data);

		addTextSection(composite);
		return composite;
	}

	private Composite createDefaultComposite(Composite parent) {
		Composite composite = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		layout.numColumns = 2;
		composite.setLayout(layout);

		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		composite.setLayoutData(data);

		return composite;
	}

	protected void performDefaults() {
		super.performDefaults();
		textText.setText(Properties.PROPERTY_DEFAULT_TEXT);
	}
	
	public boolean performOk() {
		try {
			Properties.storeText(getProject(), textText.getText());
			return true;
		} catch (Exception e) {
			return false;
		}
	}

}